@@ -18,16 +18,13 @@ if os.path.exists(os.path.join(os.getcwd(), "foci.json")):
             for value in term_map[key]:
                 FOCI_TERMS[value] = key
 
-# GITLAB
-# events
-ACTIVITY_TYPES = {
-    "coding": ["pushed", "merged"],
-    "collaboration": ["approved", "closed", "commented", "created", "updated"]
-}
+# EVENTS
+ACTIVITY_TYPE_CODING = ["pushed", "merged"]
+ACTIVITY_TYPE_COLLABORATION = ["approved", "closed", "commented", "created", "updated"]
 
 # filters
 FILTER_GROUP_NAMESPACES = [d.strip() for d in os.environ["FILTER_GITLAB_GROUP_NAMESPACES"].split(",")] if "FILTER_GITLAB_GROUP_NAMESPACES" in os.environ else list()
-FILTER_PROJECT_IDS = [d.strip() for d in os.environ["FILTER_GITLAB_PROJECT_IDS"].split(",")] if "FILTER_GITLAB_PROJECT_IDS" in os.environ else list()
+FILTER_PROJECT_IDS = [int(d.strip()) for d in os.environ["FILTER_GITLAB_PROJECT_IDS"].split(",")] if "FILTER_GITLAB_PROJECT_IDS" in os.environ else list()
 FILTER_PROJECT_NAMES = [d.strip() for d in os.environ["FILTER_GITLAB_PROJECT_NAMES"].split(",")] if "FILTER_GITLAB_PROJECT_NAMES" in os.environ else list()
 FILTER_PROJECT_NAMES_STARTSWITH = [d.strip() for d in os.environ["FILTER_GITLAB_PROJECT_NAMES_STARTSWITH"].split(",")] if "FILTER_GITLAB_PROJECT_NAMES_STARTSWITH" in os.environ else list()
 
@@ -48,6 +45,10 @@ VISIBILITY = glapi_config.GITLAB_PROJECT_VISIBILITY
 USER = os.environ["GITLAB_USER_ID"] if "GITLAB_USER_ID" in os.environ else None
 USER_ACCESS = os.environ["GITLAB_USER_PROJECT_ACCESS"] if "GITLAB_USER_PROJECT_ACCESS" in os.environ else 30
 USER_ACCESS_LEVELS = {
+    0: "no access",
+    5: "minimal",
+    10: "guest",
+    20: "reporter",
     30: "developer",
     40: "maintainer",
     50: "owner"
