@@ -1,7 +1,7 @@
 from gitrics import configuration
+from gitrics.user.user import gitricsUser
 
 from glapi.group import GitlabGroup
-from glapi.user import GitlabUser
 
 class gitricsGroupUsers(GitlabGroup):
     """
@@ -29,10 +29,10 @@ class gitricsGroupUsers(GitlabGroup):
 
         # get users
         if users:
-            self.users = [GitlabUser(user=d) for d in users]
+            self.users = [gitricsUser(user=d) for d in users]
         else:
             # try to get from api
             data = self.extract_users()
 
             # format result
-            self.users = [GitlabUser(user=d.user) for d in data] if data else None
+            self.users = [gitricsUser(user=d.user) for d in data] if data else None
